==> budb-0.0.1.jar: META-INF/leiningen/lsenta/budb/README.md <==
BuDB
====

A CRDT-based Database built for Clojure and Clojurescript. And Java and Javascript by transitivity.

The general idea of Conflict-free Replicated Data Types is to rely on 
mathematical properties (commutativty, idempotence and associativity) 
to build a funky datastorage that can go offline and stay consistent.


Usage
-----

[![Clojars Project](https://img.shields.io/clojars/v/budb.svg)](https://clojars.org/budb)
[![CircleCI](https://circleci.com/gh/lsenta/budb.svg?style=svg)](https://circleci.com/gh/lsenta/budb)

The library provides:
- a platform to describe CRDT and build the corresponding values
- examples with a Max Register and Last Writer Wins Register

TODOs
-----

- [ ] Setup correctly in circleci
- [ ] Have some way to test clojurescript with advanced optimizations


Contribute
----------

The Makefile shows the main lein commands.

```bash
git clone git@github.com:lsenta/budb.git
make test # run one shot tests
make resources # "compiles" the resources to the target folders
make figwheel # start the testbook and devbook instance
make server # start the ring server, visit http://localhost:8100/
```


License
-------

MIT License

Copyright (c) 2017 Laurent Senta

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> budb-0.0.2-20170511.084139-3.jar: META-INF/leiningen/lsenta/budb/README.md <==
BuDB
====

A CRDT-based Database built for Clojure and Clojurescript.
And Java and Javascript by transitivity.

The general idea of Conflict-free Replicated Data Types is to rely on
mathematical properties (commutativty, idempotence and associativity)
to build a funky datastorage that can go offline and stay consistent.


Usage
-----

[![Clojars Project](https://img.shields.io/clojars/v/lsenta/budb.svg)](https://clojars.org/lsenta/budb)
[![CircleCI](https://circleci.com/gh/lsenta/budb.svg?style=svg)](https://circleci.com/gh/lsenta/budb)

The library provides:
- a platform to describe CRDT and build the corresponding values
- examples with a Max Register and Last Writer Wins Register

TODOs
-----

- [ ] Setup correctly in circleci
- [ ] Have some way to test clojurescript with advanced optimizations


Contribute
----------

The Makefile shows the main lein commands.

```bash
git clone git@github.com:lsenta/budb.git
cd budb
cp ./prepare.sh.example ./prepare.sh
vim ./prepare.sh
source ./prepare.sh
make test # run one shot tests
make figwheel # start the testbook and devbook instance
```


License
-------

MIT License

Copyright (c) 2017 Laurent Senta

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
